@@ -15,7 +15,7 @@
 
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXSSH, NX protocol compression and NX extensions to this software      */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -24,7 +24,7 @@
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
+/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -1294,7 +1294,7 @@ check_host_key(char *hostname, struct sockaddr *hostaddr, u_short port,
 	if (options.check_host_ip && host_status != HOST_CHANGED &&
 	    ip_status == HOST_CHANGED) {
 		snprintf(msg, sizeof(msg),
-		    "Warning: the %s host key for '%.200s'\n"
+		    "NX> 212 Warning: the %s host key for '%.200s'\n"
 		    "differs from the key for the IP address '%.128s'"
 		    "\nOffending key for IP in %s:%d",
 		    type, host, ip, ip_file, ip_line);
